package com.example.futter_gaode_map.mapview;

import android.app.Activity;
import android.app.Application;
import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.TextView;

import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.platform.PlatformView;

import com.amap.api.maps.AMap;
import com.amap.api.maps.AMapOptions;
import com.amap.api.maps.CameraUpdateFactory;
import com.amap.api.maps.MapView;
import com.amap.api.maps.TextureMapView;
import com.amap.api.maps.UiSettings;
import com.amap.api.maps.model.LatLng;
import com.amap.api.maps.model.Marker;
import com.amap.api.maps.model.MarkerOptions;
import com.example.futter_gaode_map.AmapLocationPlugin;

import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;

import static android.speech.tts.TextToSpeech.STOPPED;
import static com.example.futter_gaode_map.AmapLocationPlugin.CREATED;
import static com.example.futter_gaode_map.AmapLocationPlugin.DESTROYED;
import static com.example.futter_gaode_map.AmapLocationPlugin.RESUMED;
import static com.example.futter_gaode_map.AmapLocationPlugin.registrar;

/**
 * Created by chenjiadi on 2019/8/5.
 */

public class MyMapView implements PlatformView, MethodChannel.MethodCallHandler, Application.ActivityLifecycleCallbacks {
    private final TextureMapView mapView;
    private AMap aMap;
    private final MethodChannel methodChannel;
    private AtomicInteger activityState;
    private boolean disposed = false;
    private int registrarActivityHashCode = registrar.activity().hashCode();
    private UiSettings mUiSettings;//定义一个UiSettings对象
    private double lat;
    private double lng;
    private String title;

    MyMapView(Context context, BinaryMessenger messenger, AtomicInteger activityState, int id, Map<String, Object> params) {
        Log.e("save", "---------------MyMapView");
        methodChannel = new MethodChannel(messenger, "plugins.nightfarmer.top/myview" + id);
        methodChannel.setMethodCallHandler(this);
        mapView = new TextureMapView(context);
        if (aMap == null) {
            aMap = mapView.getMap();
        }
        if (params.containsKey("lat")) {
             lat = Double.parseDouble(String.valueOf(params.get("lat"))) ;
          Log.e("-------settext1111lat",lat+"");
        }
        if (params.containsKey("lng")) {
             lng = Double.parseDouble(String.valueOf(params.get("lng"))) ;
            Log.e("-------settext1111lng",lng+"");
        }
        if (params.containsKey("title")) {
            title = String.valueOf(params.get("title")) ;
            Log.e("-------settext1111title",title+"");
        }
        mUiSettings = aMap.getUiSettings();//实例化UiSettings类对象
        mUiSettings.setZoomControlsEnabled(false);
        mUiSettings.setAllGesturesEnabled(false);
        LatLng latLng = new LatLng(lat,lng);
        final Marker marker = aMap.addMarker(new MarkerOptions().position(latLng).title(title));
        marker.showInfoWindow();
        aMap. moveCamera(CameraUpdateFactory.changeLatLng(latLng));

        this.activityState = activityState;
    }

    @Override
    public View getView() {
        return mapView;
    }

    public void setup() {
        switch (activityState.get()) {
            case STOPPED:
                mapView.onCreate(null);
                mapView.onResume();
                mapView.onPause();
                break;
            case RESUMED:
                mapView.onCreate(null);
                mapView.onResume();
                break;
            case CREATED:
                mapView.onCreate(null);
                break;
            case DESTROYED:

                break;
            default:
                throw new IllegalArgumentException("Cannot interpret " + activityState.get() + " as an activity activityState");

        }

        // 注册生命周期
        registrar.activity().getApplication().registerActivityLifecycleCallbacks(this);
    }

    @Override
    public void onMethodCall(MethodCall methodCall, MethodChannel.Result result) {
        switch (methodCall.method) {
            case "setText":
                Log.e("-------settext", (String) methodCall.arguments);
                break;
            default:
                result.notImplemented();
        }

    }


    @Override
    public void dispose() {
        if (disposed) {
            return;
        }
        disposed = true;
        mapView.onDestroy();

        registrar.activity().getApplication().unregisterActivityLifecycleCallbacks(this);
    }

    @Override
    public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
        if (disposed || activity.hashCode() != registrarActivityHashCode) {
            return;
        }
        Log.e("save", "---------------onActivityCreated");
        mapView.onCreate(savedInstanceState);
    }

    @Override
    public void onActivityStarted(Activity activity) {
        if (disposed || activity.hashCode() != registrarActivityHashCode) {
            return;
        }
        Log.e("save", "---------------onActivityStarted");
    }

    @Override
    public void onActivityResumed(Activity activity) {
        if (disposed || activity.hashCode() != registrarActivityHashCode) {
            return;
        }
        Log.e("save", "---------------onActivityResumed");
        mapView.onResume();
    }

    @Override
    public void onActivityPaused(Activity activity) {
        if (disposed || activity.hashCode() != registrarActivityHashCode) {
            return;
        }
        Log.e("save", "---------------onActivityPaused");
        mapView.onPause();
    }

    @Override
    public void onActivityStopped(Activity activity) {
        if (disposed || activity.hashCode() != registrarActivityHashCode) {
            return;
        }
        Log.e("save", "---------------onActivityStopped");
    }

    @Override
    public void onActivitySaveInstanceState(Activity activity, Bundle outState) {
        if (disposed || activity.hashCode() != registrarActivityHashCode) {
            return;
        }
        Log.e("save", "---------------onActivitySaveInstanceState");
        mapView.onSaveInstanceState(outState);
    }

    @Override
    public void onActivityDestroyed(Activity activity) {
        if (disposed || activity.hashCode() != registrarActivityHashCode) {
            return;
        }
        Log.e("save", "---------------onActivityDestroyed");
        mapView.onDestroy();
    }
}